# The John Snow Labs Library
The John Snow Labs Library gives you access to all of John Snow Labs Enterprise and Open Source products in an easy and simple manner.             
Access 10000+ state-of-the-art NLP and OCR models for `Finance`, `Legal`,`Medical` and many other domains which effortlessly scales to big data clusters.               
See https://www.johnsnowlabs.com/  and [the docs](https://nlu.johnsnowlabs.com/docs/en/install) for more details     

To install the NLP Libraries in your environment:

1. Get a license key in your [my.johnsnowlabs.com](https://my.johnsnowlabs.com/) account. If you do not have one, get a trial license [here](https://www.johnsnowlabs.com/install/).
2. In your shell, run:
```shell
pip install johnsnowlabs
````

3. In a Python shell, run :
```shell
from johnsnowlabs import spark_nlp  
nlp.install()
````
